%global libsomajor 0.0
%bcond_with doc

Summary:        Network configuration tool using YAML
Name:           netplan
Version:        0.106
Release:        1%{?dist}
License:        GPL-3.0-only
URL:            http://netplan.io/
Source0:        https://github.com/canonical/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

Patch0001:      https://github.com/canonical/netplan/commit/bbbba80c7d114490dd0c99acc962b81ed2d12fe0.patch
Patch0002:      https://github.com/canonical/netplan/commit/e410b3eb48654e2b9d6e47cf58e1df25e99a9449.patch
Patch0003:      https://github.com/slyon/netplan/commit/c827800ad6a24f1d43e1542874095b47eb795b2f.patch

BuildRequires:  gcc meson
BuildRequires:  pkgconfig(bash-completion) pkgconfig(glib-2.0) pkgconfig(gio-2.0) pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd) pkgconfig(yaml-0.1) pkgconfig(uuid) python3-devel python3-cffi
BuildRequires:  python3dist(coverage) python3dist(netifaces) python3dist(pycodestyle) python3dist(pyflakes) 
BuildRequires:  python3dist(pytest) python3dist(pytest-cov) python3dist(pyyaml) python3dist(rich)
BuildRequires:  pkgconfig(cmocka) python3-dbus
BuildRequires:  systemd-rpm-macros
BuildRequires:  dbus-x11
BuildRequires:  %{_bindir}/find
BuildRequires:  %{_sbindir}/ip
BuildRequires:  %{_bindir}/ovs-vsctl
%if %{with doc}
BuildRequires:  %{_bindir}/pandoc
%endif
Requires:       python3dist(netifaces) python3dist(pyyaml) python3dist(rich)
Requires:       %{_sbindir}/ip
Requires:       dbus-common
Requires:       %{name}-libs = %{version}-%{release}
Requires:       %{name}-default-backend
Suggests:       %{name}-default-backend-NetworkManager


%description
netplan reads network configuration from /etc/netplan/*.yaml which are written by administrators,
installers, cloud image instantiations, or other OS deployments. During early boot, it generates
backend specific configuration files in /run to hand off control of devices to a particular
networking daemon.

Currently supported backends are NetworkManager and systemd-networkd.


%package libs
Summary:        Network configuration tool using YAML (core library)

%description libs
netplan reads network configuration from /etc/netplan/*.yaml which are written by administrators,
installers, cloud image instantiations, or other OS deployments. During early boot, it generates
backend specific configuration files in /run to hand off control of devices to a particular
networking daemon.

This package provides Netplan's core libraries.


%package devel
Summary:        Network configuration tool using YAML (development files)
Requires:       %{name}-libs = %{version}-%{release}

%description devel
netplan reads network configuration from /etc/netplan/*.yaml which are written by administrators,
installers, cloud image instantiations, or other OS deployments. During early boot, it generates
backend specific configuration files in /run to hand off control of devices to a particular
networking daemon.

This package provides development headers and libraries for building applications using Netplan.


%package default-backend-NetworkManager
Summary:        Network configuration tool using YAML (NetworkManager backend)
Requires:       %{name} = %{version}-%{release}
Requires:       NetworkManager
Requires:       NetworkManager-config-server
Recommends:     (NetworkManager-wifi if linux-firmware)
Suggests:       NetworkManager-wifi
Conflicts:      %{name}-default-backend
Provides:       %{name}-default-backend

BuildArch:      noarch

%description default-backend-NetworkManager
netplan reads network configuration from /etc/netplan/*.yaml which are written by administrators,
installers, cloud image instantiations, or other OS deployments. During early boot, it generates
backend specific configuration files in /run to hand off control of devices to a particular
networking daemon.

This package configures Netplan to use NetworkManager as its backend.



%prep
%autosetup -p1

sed -e "s/werror=true/werror=false/g" -i meson.build
sed -i 's/egrep/grep -E/g' tests/validate_docs.sh
sed -i '/import netplan.libnetplan as libnetplan/d' netplan/cli/commands/try_command.py


%build
%meson
%meson_build


%install
%meson_install

rm -f %{buildroot}/lib/netplan/generate
rmdir %{buildroot}/lib/netplan
rmdir %{buildroot}/lib

mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_prefix}/lib/%{name}

cat > %{buildroot}%{_prefix}/lib/%{name}/00-netplan-default-renderer-nm.yaml <<EOF
network:
  renderer: NetworkManager
EOF


%check
%meson_test


%files
%license COPYING
%doc %{_docdir}/%{name}/
%{_sbindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/dbus-1/system-services/io.netplan.Netplan.service
%{_datadir}/dbus-1/system.d/io.netplan.Netplan.conf
%{_systemdgeneratordir}/%{name}
%if %{with doc}
%{_mandir}/man5/%{name}.5*
%{_mandir}/man8/%{name}*.8*
%endif
%dir %{_sysconfdir}/%{name}
%dir %{_prefix}/lib/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/bash-completion/completions/%{name}


%files libs
%license COPYING
%{_libdir}/libnetplan.so.%{libsomajor}{,.*}


%files devel
%{_includedir}/%{name}/
%{_libdir}/libnetplan.so
%{_libdir}/pkgconfig/%{name}.pc


%files default-backend-NetworkManager
%{_prefix}/lib/%{name}/00-netplan-default-renderer-nm.yaml


%changelog
* Mon Nov 20 2023 Miaojun Dong <zoedong@tencent.com> - 0.106-1
- Initial Build
